@@ -24,28 +24,8 @@
 #include <sys/stat.h>
 #include <sys/mman.h>
 #include "gnome-mime.h"
+#include "gnome-magic.h"
 
-typedef enum {
-  T_END /* end of array */, T_BYTE, T_SHORT, T_LONG, T_STR, T_DATE, 
-  T_BESHORT, T_BELONG, T_BEDATE,
-  T_LESHORT, T_LELONG, T_LEDATE
-} GnomeMagicType;
-
-typedef struct _GnomeMagicEntry {
-  guint32 mask;
-  GnomeMagicType type;
-  guint16 offset, level;
-
-  char test[48];
-  guchar test_len;
-  enum { CHECK_EQUAL, CHECK_LT, CHECK_GT, CHECK_AND, CHECK_XOR,
-	 CHECK_ANY } comptype;
-  guint32 compval;
-
-  char mimetype[48];
-} GnomeMagicEntry;
-
-#ifndef GEN_MIMEDB
 /****** misc lame parsing routines *******/
 static guchar
 read_octal_str(char **pos)
@@ -387,6 +367,16 @@ gnome_magic_db_load(void)
   return retval;
 }
 
+/**
+ * gnome_mime_type_from_magic:
+ * @filename: an existing file name for which we want to guess the mime-type
+ *
+ * This routine uses a magic database as described in magic(5) that maps
+ * files into their mime-type (so our modified magic database contains mime-types
+ * rather than textual descriptions of the files).
+ *
+ * Returns a pointer to an internal copy of the mime-type for @filename.
+ */
 const char *
 gnome_mime_type_from_magic(const gchar *filename)
 {
@@ -438,4 +428,3 @@ gnome_mime_type_from_magic(const gchar *filename)
   return (ents[i].type == T_END)?NULL:ents[i].mimetype;
 }
 
-#endif
