@@ -556,9 +556,11 @@ install_menuitem_hint_to_appbar(GnomeUIInfo* uiinfo, GnomeAppBar* bar)
     }
 }
 
-static void
+void
 gnome_app_ui_configure_configurable (GnomeUIInfo* uiinfo)
 {
+  if (uiinfo->type == GNOME_APP_UI_ITEM_CONFIGURABLE)
+  {
         GnomeUIInfoConfigurableTypes type = (GnomeUIInfoConfigurableTypes) uiinfo->accelerator_key;
 	
 	gboolean accelerator_key_def;
@@ -626,6 +628,7 @@ gnome_app_ui_configure_configurable (GnomeUIInfo* uiinfo)
 
 	
 	uiinfo->type = GNOME_APP_UI_ITEM;
+  }
 }
 
 void
@@ -774,7 +777,7 @@ create_menu_item (GnomeUIInfo *uiinfo, int is_radio, GSList **radio_group,
 	if ((uiinfo->type == GNOME_APP_UI_TOGGLEITEM) || is_radio) {
 		gtk_check_menu_item_set_show_toggle
 			(GTK_CHECK_MENU_ITEM(uiinfo->widget), TRUE);
-		gtk_check_menu_item_set_state
+		gtk_check_menu_item_set_active
 			(GTK_CHECK_MENU_ITEM (uiinfo->widget), FALSE);
 	}
 
