@@ -369,7 +369,7 @@ set_result(GnomeCalculator *gc)
 static void
 unselect_invert(GnomeCalculator *gc)
 {
-	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(gc->invert_button),
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gc->invert_button),
 				    FALSE);
 	gc->invert=FALSE;
 }
@@ -567,13 +567,10 @@ clear_calc(GtkWidget *w, gpointer data)
 
 	g_return_val_if_fail(gc!=NULL,TRUE);
 
-	while(gc->stack)
-		stack_pop(&gc->stack);
-
 	gc->result = 0;
 	strcpy(gc->result_string,"0");
-	gc->invert = FALSE;
 	gc->error = FALSE;
+	gc->invert = FALSE;
 
 	gc->add_digit = TRUE;
 	push_input(gc);
