@@ -338,10 +338,13 @@ client_set_ghash (GnomeClient *client, gchar *name, GHashTable *table)
   if (!GNOME_CLIENT_CONNECTED (client))
     return;
   
-  argc= g_hash_table_size (table);
+  argc = g_hash_table_size (table);
+
+  if (argc == 0) 
+    return;
   
   /* Now initialize the 'vals' array.  */
-  vals= g_new (SmPropValue, argc);
+  vals = g_new (SmPropValue, argc);
   tmp = vals;
   
   g_hash_table_foreach (table, (GHFunc) client_set_ghash0, &tmp);
@@ -802,7 +805,7 @@ client_parse_func (poptContext ctx,
     {
       /* Option: --sm-config-prefix  */
       master_client->config_prefix= g_strdup (arg);
-      master_client_restored= TRUE;    
+      master_client_restored = TRUE;    
     }
   else if (key == -3)
     {
@@ -824,6 +827,15 @@ gnome_client_disable_master_connection (void)
   gnome_client_auto_connect_master= FALSE;
 }
 
+/* Called at exit to ensure the ice connection is closed cleanly
+ * This avoids io errors on the session manager side */
+static void  
+master_client_clean_up (void)
+{
+  if (GNOME_CLIENT_CONNECTED (master_client))
+      gnome_client_disconnect (master_client);
+}
+
 static void
 master_client_connect (GnomeClient *client,
 		       gint         restarted,
@@ -836,7 +848,9 @@ master_client_connect (GnomeClient *client,
 		   XInternAtom(gdk_display, sm_client_id_prop, False),
 		   XA_STRING, 8, GDK_PROP_MODE_REPLACE,
 		   (unsigned char *) client_id,
-		   strlen(client_id));               
+		   strlen(client_id));
+
+  g_atexit (master_client_clean_up);
 }
 
 static void
