@@ -29,6 +29,8 @@ enum {
 	WIDTH_CHANGED,
 	EDITING_STARTED,
 	EDITING_STOPPED,
+	SELECTION_STARTED,
+	SELECTION_STOPPED,
 	LAST_SIGNAL
 };
 
@@ -562,13 +564,16 @@ static void
 iti_start_selecting (Iti *iti, int idx, guint32 event_time)
 {
 	GtkEditable *e = GTK_EDITABLE (iti->entry);
+	GdkCursor *ibeam;
 	
 	gtk_editable_select_region (e, idx, idx);
 	gtk_editable_set_position (e, idx);
+	ibeam = gdk_cursor_new (GDK_XTERM);
 	gnome_canvas_item_grab (GNOME_CANVAS_ITEM (iti),
 				GDK_BUTTON_RELEASE_MASK |
 				GDK_POINTER_MOTION_MASK,
-				NULL, event_time);
+				ibeam, event_time);
+	gdk_cursor_destroy (ibeam);
 
 	gtk_editable_select_region (e, idx, idx);
 	e->current_pos = e->selection_start_pos;
@@ -576,6 +581,8 @@ iti_start_selecting (Iti *iti, int idx, guint32 event_time)
 	iti->selecting = TRUE;
 
 	iti_queue_redraw (iti);
+
+	gtk_signal_emit (GTK_OBJECT (iti), iti_signals[SELECTION_STARTED]);
 }
 
 /*
@@ -594,6 +601,7 @@ iti_stop_selecting (Iti *iti, guint32 event_time)
 	iti->selecting = FALSE;
 
 	iti_queue_redraw (iti);
+	gtk_signal_emit (GTK_OBJECT (iti), iti_signals[SELECTION_STOPPED]);
 }
 
 /*
@@ -796,6 +804,24 @@ iti_class_init (GnomeIconTextItemClass *text_item_class)
 			gtk_marshal_NONE__NONE,
 			GTK_TYPE_NONE, 0);
 
+	iti_signals[SELECTION_STARTED] =
+		gtk_signal_new (
+			"selection_started",
+			GTK_RUN_FIRST,
+			object_class->type,
+			GTK_SIGNAL_OFFSET (GnomeIconTextItemClass, selection_started),
+			gtk_marshal_NONE__NONE,
+			GTK_TYPE_NONE, 0);
+
+	iti_signals[SELECTION_STOPPED] =
+		gtk_signal_new (
+			"selection_stopped",
+			GTK_RUN_FIRST,
+			object_class->type,
+			GTK_SIGNAL_OFFSET (GnomeIconTextItemClass, selection_stopped),
+			gtk_marshal_NONE__NONE,
+			GTK_TYPE_NONE, 0);
+
 	gtk_object_class_add_signals (object_class, iti_signals, LAST_SIGNAL);
 }
 
