@@ -49,7 +49,8 @@ static const char *goad_activation_id = NULL;
 
 static void goad_server_list_read(const char *filename,
 				  GArray *servinfo,
-				  GString *tmpstr);
+				  GString *tmpstr,
+				  GoadServerList *newl);
 static GoadServerType goad_server_typename_to_type(const char *typename);
 static CORBA_Object real_goad_server_activate(GoadServer *sinfo,
 					      GoadActivationFlags flags,
@@ -110,9 +111,13 @@ goad_server_list_get(void)
   GString *usersrvpath;
   DIR *dirh;
   GoadServerList *newl;
+  GHashTable *by_goad_id;
+  int i;
 
   newl = g_new0(GoadServerList, 1);
   servinfo = g_array_new(TRUE, FALSE, sizeof(GoadServer));
+  by_goad_id = g_hash_table_new(g_str_hash, g_str_equal);
+  newl->by_goad_id = by_goad_id;
   tmpstr = g_string_new(NULL);
 
   /* User servers (preferred over system) */
@@ -128,7 +133,7 @@ goad_server_list_get(void)
 	    
 	    g_string_sprintf(tmpstr, "=%s/%s", usersrvpath->str, dent->d_name);
 	    
-	    goad_server_list_read(tmpstr->str, servinfo, tmpstr);
+	    goad_server_list_read(tmpstr->str, servinfo, tmpstr, newl);
     }
     closedir(dirh);
   }
@@ -146,14 +151,18 @@ goad_server_list_get(void)
       g_string_sprintf(tmpstr, "=" GNOMESYSCONFDIR SERVER_LISTING_PATH "/%s",
 		       dent->d_name);
 		       
-      goad_server_list_read(tmpstr->str, servinfo, tmpstr);
+      goad_server_list_read(tmpstr->str, servinfo, tmpstr, newl);
     }
     closedir(dirh);
   }
 
-  goad_server_list_read(SERVER_LISTING_PATH "/", servinfo, tmpstr);
+  goad_server_list_read(SERVER_LISTING_PATH "/", servinfo, tmpstr, newl);
 
   newl->list = (GoadServer *)servinfo->data;
+  for(i = 0; newl->list[i].repo_id; i++)
+    g_hash_table_insert(newl->by_goad_id,
+			newl->list[i].server_id, &newl->list[i]);
+
   g_array_free(servinfo, FALSE);
   g_string_free(tmpstr, TRUE);
 
@@ -258,11 +267,12 @@ goad_server_typename_to_type(const char *typename)
 static void
 goad_server_list_read(const char *filename,
 		      GArray *servinfo,
-		      GString *tmpstr)
+		      GString *tmpstr,
+		      GoadServerList *newl)
 {
   gpointer iter;
   char *typename;
-  GoadServer newval;
+  GoadServer newval, *nvptr;
   GString*   dummy;
 
   dummy = g_string_new("");
@@ -325,6 +335,7 @@ goad_server_list_read(const char *filename,
     newval.location_info = gnome_config_get_string(dummy->str);
     g_array_append_val(servinfo, newval);
   }
+
   gnome_config_pop_prefix();
   /*forget the config information about this file, otherwise we
     take up gobs of memory*/
@@ -365,6 +376,8 @@ goad_server_list_free (GoadServerList *server_list)
     g_free(sl);
   }
 
+  g_hash_table_destroy(server_list->by_goad_id);
+
   g_free(server_list);
 }
 
@@ -388,7 +401,6 @@ goad_server_activate_with_id (GoadServerList *server_list,
   GoadServerList *my_servlist;
   GoadServer *slist;
   CORBA_Object retval = CORBA_OBJECT_NIL;
-  int i;
 
   g_return_val_if_fail(server_id, CORBA_OBJECT_NIL);
   g_return_val_if_fail(!((flags & GOAD_ACTIVATE_EXISTING_ONLY)
@@ -409,13 +421,10 @@ goad_server_activate_with_id (GoadServerList *server_list,
   if(!slist)
     goto errout;
 
-  for(i = 0; slist[i].repo_id; i++) {
-    if(!strcmp(slist[i].server_id, server_id))
-      break;
-  }
+  slist = g_hash_table_lookup(my_servlist->by_goad_id, server_id);
 
-  if(slist[i].repo_id)
-    retval = real_goad_server_activate(&slist[i], flags, params, my_servlist);
+  if(slist)
+    retval = real_goad_server_activate(slist, flags, params, my_servlist);
 
  errout:
   if(!server_list)
@@ -814,6 +823,7 @@ goad_server_unregister_atexit(ActiveServerInfo *ai, CORBA_Environment *ev)
 
   CORBA_Object_release(name_service, ev);
 }
+
 static void
 goad_servers_unregister_atexit(void)
 {
