@@ -28,9 +28,9 @@
  */
 #include <config.h>
 
-/* needed for sigaction under 'gcc -ansi -pedantic' on GNU/Linux */
-#ifndef _POSIX_SOURCE
-#  define _POSIX_SOURCE 1
+/* Use this to pull SCM_RIGHTS definition on IRIX */
+#if defined(irix) || defined (__irix__) || defined(sgi) || defined (__sgi__)
+#    define _XOPEN_SOURCE
 #endif
 
 #include <sys/types.h>
@@ -38,6 +38,7 @@
 #include <sys/resource.h>
 #include <limits.h>
 #include <unistd.h>
+#include <string.h>
 #include <signal.h>
 #include <fcntl.h>
 #include <termios.h>
@@ -181,7 +182,7 @@ pty_remove (pty_info *pi)
 
 	last = (void *) 0;
 	
-	for (l = pty_list; l; l = pi->next){
+	for (l = pty_list; l; l = l->next){
 		if (l == pi){
 			if (last == (void *) 0)
 				pty_list = pi->next;
@@ -189,8 +190,9 @@ pty_remove (pty_info *pi)
 				last->next = pi->next;
 			free (pi->line);
 			pty_free (pi);
-			break;
+			return;
 		}
+		last = l;
 	}
 
 	exit (1);
@@ -242,6 +244,20 @@ pty_add (int master_fd, int slave_fd, char *line)
 	return pi;
 }
 
+static int
+path_max (void)
+{
+#ifdef _PC_PATH_MAX
+	return pathconf ("/", _PC_PATH_MAX);
+#else
+#  ifdef PATH_MAX
+	return PATH_MAX;
+#  else
+	return 1024;
+#  endif
+#endif
+}
+
 static int
 open_ptys (int update_db)
 {
@@ -249,8 +265,9 @@ open_ptys (int update_db)
 	int status, master_pty, slave_pty;
 	pty_info *p;
 	int result;
-
-	term_name = alloca (PATH_MAX) + 1;
+	int size;
+	
+	term_name = ((char *)alloca (path_max())) + 1;
 	
 	status = openpty (&master_pty, &slave_pty, term_name, NULL, NULL);
 	if (status == -1){
@@ -366,7 +383,7 @@ sanity_checks (void)
 	if (fcntl (2, F_GETFL, &flag) == EBADF){
 		stderr_fd = open ("/dev/tty", O_RDWR);
 		if (stderr_fd == -1){
-			stderr_fd = open ("/dev/nulll", O_RDWR);
+			stderr_fd = open ("/dev/null", O_RDWR);
 			if (stderr_fd == -1)
 				exit (1);
 		}
